@@ -12,8 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import List
+from typing import List, Union
 
+from google.api_core.exceptions import InvalidArgument
+from google.api_core.operation import Operation
 from google.protobuf.field_mask_pb2 import FieldMask
 
 from google.cloud.pubsublite.admin_client_interface import AdminClientInterface
@@ -23,6 +25,8 @@ from google.cloud.pubsublite.types import (
     LocationPath,
     TopicPath,
     BacklogLocation,
+    PublishTime,
+    EventTime,
 )
 from google.cloud.pubsublite.types.paths import ReservationPath
 from google.cloud.pubsublite_v1 import (
@@ -31,6 +35,8 @@ from google.cloud.pubsublite_v1 import (
     AdminServiceClient,
     TopicPartitions,
     Reservation,
+    TimeTarget,
+    SeekSubscriptionRequest,
 )
 
 
@@ -105,6 +111,25 @@ class AdminClientImpl(AdminClientInterface):
             subscription=subscription, update_mask=update_mask
         )
 
+    def seek_subscription(
+        self,
+        subscription_path: SubscriptionPath,
+        target: Union[BacklogLocation, PublishTime, EventTime],
+    ) -> Operation:
+        request = SeekSubscriptionRequest(name=str(subscription_path))
+        if isinstance(target, PublishTime):
+            request.time_target = TimeTarget(publish_time=target.value)
+        elif isinstance(target, EventTime):
+            request.time_target = TimeTarget(event_time=target.value)
+        elif isinstance(target, BacklogLocation):
+            if target == BacklogLocation.END:
+                request.named_target = SeekSubscriptionRequest.NamedTarget.HEAD
+            else:
+                request.named_target = SeekSubscriptionRequest.NamedTarget.TAIL
+        else:
+            raise InvalidArgument("A valid seek target must be specified.")
+        return self._underlying.seek_subscription(request=request)
+
     def delete_subscription(self, subscription_path: SubscriptionPath):
         self._underlying.delete_subscription(name=str(subscription_path))
 
